@@ -1,4 +1,4 @@
-### $Id: zzz.R,v 1.1 1999/11/04 16:42:28 saikat Exp $
+### $Id: zzz.R,v 1.2 2000/03/30 00:07:26 bates Exp $
 ###
 ### nlme for R
 ###
@@ -9,13 +9,13 @@
 ### It is made available under the terms of the GNU General Public
 ### License, version 2, or at your option, any later version,
 ### incorporated herein by reference.
-### 
+###
 ### This program is distributed in the hope that it will be
 ### useful, but WITHOUT ANY WARRANTY; without even the implied
 ### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 ### PURPOSE.  See the GNU General Public License for more
 ### details.
-### 
+###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
 ### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
@@ -24,3 +24,5 @@
 .First.lib <- function(lib, pkg) {
   library.dynam( "nlme", pkg, lib )
 }
+
+provide(nlme)
